from django.conf.urls import url, include

from ovp_core import views

urlpatterns = [
  url("^startup/$", views.startup, name="startup"),
  url("^contact/$", views.contact, name="contact"),
  url("^lead/$", views.record_lead, name="lead"),
]



from ovp_core import models
from rest_framework import serializers


class CauseSerializer(serializers.ModelSerializer):
  name = serializers.CharField(required=False)

  class Meta:
    fields = ['id', 'name']
    model = models.Cause



from ovp_core import models
from rest_framework import serializers


class GoogleAddressCityStateSerializer(serializers.ModelSerializer):
  class Meta:
    model = models.GoogleAddress
    fields = ['city_state']




from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

import csv
from django.http import HttpResponse

from ovp_core.models import Lead


def export_all_as_csv(model_admin, request, queryset):
	if not request.user.is_staff:
		raise PermissionDenied

	response = HttpResponse(content_type='text/csv')
	response['Content-Disposition'] = 'attachment; filename="leads.csv"'

	csv_writer = csv.writer(response)
	for lead in queryset.all():
		csv_writer.writerow([lead.email, lead.name or '', lead.phone or '', lead.country or ''])

	return response


class LeadAdmin(admin.ModelAdmin):
	fields = ['id', 'name', 'email', 'phone']
	list_display = ['id', 'name', 'email', 'phone']
	list_filter = []
	list_editable = ['name']
	search_fields = ['id', 'name', 'email', 'phone']
	readonly_fields = ['id']
	raw_id_fields = []

	actions = [export_all_as_csv]

	def changelist_view(self, request, extra_context=None):
		if 'action' in request.POST and request.POST['action'] == 'export_all_as_csv':
			if not request.POST.getlist(admin.ACTION_CHECKBOX_NAME):
				post = request.POST.copy()
				for u in Lead.objects.all():
					post.update({admin.ACTION_CHECKBOX_NAME: str(u.id)})
				request._set_post(post)
		return super(LeadAdmin, self).changelist_view(request, extra_context)

admin.site.register(Lead, LeadAdmin)





from ovp_core import models
from rest_framework import serializers


class GoogleAddressLatLngSerializer(serializers.ModelSerializer):
  class Meta:
    model = models.GoogleAddress
    fields = ['typed_address', 'typed_address2', 'address_line', 'city_state', 'lat', 'lng']
    read_only_fields = ['address_line', 'city_state']



from django.db import models
from django.utils.translation import ugettext_lazy as _

class Lead(models.Model):
  name = models.CharField(_('Name'), max_length=100, null=True, blank=True)
  email = models.CharField(_('Email'), max_length=100)
  phone = models.CharField(_('Phone'), max_length=30, null=True, blank=True)
  country = models.CharField(_('Country'), max_length=2, null=True, blank=True)

  class Meta:
    app_label = 'ovp_core'
    verbose_name = _('Lead')
    verbose_name_plural = _('Leads')



class CountryFilterMixin():
  def filter_by_country(self, request, query_set, address_param):
    if request.user.is_superuser:
      return query_set

    user_groups = request.user.groups.all()
    if len(user_groups) == 0:
      return query_set.filter(owner=user)

    user_countries = []
    for group in user_groups:
      if group.name.startswith('mng-'):
        user_countries.append(group.name.split('-')[1].upper())

    if len(user_countries) == 0:
      return query_set.filter(owner=user)

    filter_params = {}

    filter_params[address_param + '__address_components__short_name__in'] = user_countries
    filter_params[address_param + '__address_components__types__name__exact'] = 'country'

    return query_set.filter(**filter_params)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-17 20:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0006_merge_20170112_2144'),
    ]

    operations = [
        migrations.CreateModel(
            name='Lead',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name')),
                ('email', models.CharField(max_length=100, verbose_name='Email')),
                ('phone', models.CharField(blank=True, max_length=30, null=True, verbose_name='Phone')),
                ('country', models.CharField(blank=True, max_length=2, null=True, verbose_name='Country')),
            ],
            options={
                'verbose_name_plural': 'Leads',
                'verbose_name': 'Lead',
            },
        ),
    ]



from ovp_core import models
from rest_framework import serializers


class LeadSerializer(serializers.ModelSerializer):
  class Meta:
    fields = ['name', 'email', 'phone', 'country']
    model = models.Lead



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 14:17
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0004_load_skills_and_causes'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cause',
            options={'verbose_name': 'cause'},
        ),
    ]



from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from ovp_core.models import Cause

class CauseInline(admin.TabularInline):
  model = Cause


class CauseAdmin(admin.ModelAdmin):
	fields = ['id', 'name']

	list_display = ['id', 'name']

	list_filter = []

	list_editable = ['name']

	search_fields = ['id', 'name']

	readonly_fields = ['id']

	raw_id_fields = []


admin.site.register(Cause, CauseAdmin)


